<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Foundation.Collections

Windows Runtime (WinRT) APIs for for the `Windows.Foundation.Collections` namespace.

This package provides the `winrt.windows.foundation.collections` module.
